# OnnxEditorV3

It is a qt based onnx editor by pure python

## Install

``` bash
pip install onnxeditor
```

## Support List

 -  Graph Input / Output
    - Add / Remove
    - Edit shape
 - Graph Node
   - Add / Remove
   - Edit `name`
   - Edit `op_type`
   - Edit `attribute`
     - **Not support edit tensor yet**

## Todo List

 - [ ] Support Tensor Edit

## Knowed Issue

 - Sorry, we not test for all case :<
